@@ -27,7 +27,7 @@
 int count = 0;
 
 int
-main(int argc, char **argv)
+mynewt_main(int argc, char **argv)
 {
     sysinit();
 
