@@ -626,7 +626,7 @@ usage(int rc)
 }
 
 int
-main(int argc, char **argv)
+mynewt_main(int argc, char **argv)
 {
     FILE *fp;
     int fd;
