@@ -449,12 +449,8 @@ sensor_ble_oic_server_init(void)
  * @return int NOTE: this function should never return!
  */
 int
-main(int argc, char **argv)
+mynewt_main(int argc, char **argv)
 {
-
-#ifdef ARCH_sim
-    mcu_sim_parse_args(argc, argv);
-#endif
     /* Initialize OS */
     sysinit();
 
