@@ -90,7 +90,7 @@ fcb_init(struct fcb *fcb)
     assert((fcb->f_align & (fcb->f_align - 1)) == 0);
 
     while (1) {
-        rc = fcb_getnext_in_area(fcb, &fcb->f_active);
+        rc = fcb_getnext_in_area(fcb, NULL, &fcb->f_active);
         if (rc == FCB_ERR_NOVAR) {
             rc = FCB_OK;
             break;
@@ -110,6 +110,12 @@ fcb_free_sector_cnt(struct fcb *fcb)
 {
     int i;
     struct flash_area *fa;
+    int rc = 0;
+
+    rc = os_mutex_pend(&fcb->f_mtx, OS_WAIT_FOREVER);
+    if (rc && rc != OS_NOT_STARTED) {
+        return FCB_ERR_ARGS;
+    }
 
     fa = fcb->f_active.fe_area;
     for (i = 0; i < fcb->f_sector_cnt; i++) {
@@ -118,14 +124,40 @@ fcb_free_sector_cnt(struct fcb *fcb)
             break;
         }
     }
+
+    os_mutex_release(&fcb->f_mtx);
+
     return i;
 }
 
+int
+fcb_is_empty_nolock(struct fcb *fcb)
+{
+    bool ret = false;
+
+    ret = (fcb->f_active.fe_area == fcb->f_oldest &&
+           fcb->f_active.fe_elem_off == sizeof(struct fcb_disk_area));
+
+    return ret;
+}
+
 int
 fcb_is_empty(struct fcb *fcb)
 {
-    return (fcb->f_active.fe_area == fcb->f_oldest &&
+    int rc = 0;
+    bool ret = false;
+
+    rc = os_mutex_pend(&fcb->f_mtx, OS_WAIT_FOREVER);
+    if (rc && rc != OS_NOT_STARTED) {
+        return FCB_ERR_ARGS;
+    }
+
+    ret = (fcb->f_active.fe_area == fcb->f_oldest &&
       fcb->f_active.fe_elem_off == sizeof(struct fcb_disk_area));
+
+    os_mutex_release(&fcb->f_mtx);
+
+    return ret;
 }
 
 /**
@@ -226,8 +258,14 @@ fcb_offset_last_n(struct fcb *fcb, uint8_t entries,
         struct fcb_entry *last_n_entry)
 {
     struct fcb_entry loc;
+    int rc = 0;
     int i;
 
+    rc = os_mutex_pend(&fcb->f_mtx, OS_WAIT_FOREVER);
+    if (rc && rc != OS_NOT_STARTED) {
+        return FCB_ERR_ARGS;
+    }
+
     /* assure a minimum amount of entries */
     if (!entries) {
         entries = 1;
@@ -235,17 +273,19 @@ fcb_offset_last_n(struct fcb *fcb, uint8_t entries,
 
     i = 0;
     memset(&loc, 0, sizeof(loc));
-    while (!fcb_getnext(fcb, &loc)) {
+    while (!fcb_getnext_nolock(fcb, &loc)) {
         if (i == 0) {
             /* Start from the beginning of fcb entries */
             *last_n_entry = loc;
         } else if (i > (entries - 1)) {
             /* Update last_n_entry after n entries and keep updating */
-            fcb_getnext(fcb, last_n_entry);
+            fcb_getnext_nolock(fcb, last_n_entry);
         }
         i++;
     }
 
+    os_mutex_release(&fcb->f_mtx);
+
     return (i == 0) ? FCB_ERR_NOVAR : 0;
 }
 
@@ -257,14 +297,21 @@ fcb_offset_last_n(struct fcb *fcb, uint8_t entries,
 int
 fcb_clear(struct fcb *fcb)
 {
-    int rc;
+    int rc = 0;
 
-    rc = 0;
-    while (!fcb_is_empty(fcb)) {
+    rc = os_mutex_pend(&fcb->f_mtx, OS_WAIT_FOREVER);
+    if (rc && rc != OS_NOT_STARTED) {
+        return FCB_ERR_ARGS;
+    }
+
+    while (!fcb_is_empty_nolock(fcb)) {
         rc = fcb_rotate(fcb);
         if (rc) {
             break;
         }
     }
+
+    os_mutex_release(&fcb->f_mtx);
+
     return rc;
 }
