@@ -29,9 +29,6 @@ struct fs_ops;
 struct fs_ops *fs_ops_for(const char *fs_name);
 struct fs_ops *safe_fs_ops_for(const char *fs_name);
 
-#if MYNEWT_VAL(FS_CLI)
-void fs_cli_init(void);
-#endif
 
 #ifdef __cplusplus
 }
