@@ -23,6 +23,7 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include "os/mynewt.h"
+#include "mynewt_cm.h"
 #include "bsp/bsp.h"
 #include "hal/hal_bsp.h"
 #include "hal/hal_flash_int.h"
@@ -270,4 +271,5 @@ hal_bsp_init(void)
 void
 hal_bsp_deinit(void)
 {
+    Cortex_DisableAll();
 }
