@@ -51,7 +51,7 @@ static sec_data_secret struct eflash_nrf5x_dev enc_flash_dev0 = {
         .efd_hal = {
             .hf_itf = &enc_flash_funcs,
         },
-        .efd_hwdev = &nrf52k_flash_dev
+        .efd_hwdev = &nrf_flash_dev
     }
 };
 
@@ -64,7 +64,7 @@ hal_bsp_flash_dev(uint8_t id)
      * Internal flash mapped to id 0.
      */
     if (id == 0) {
-        return &nrf52k_flash_dev;
+        return &nrf_flash_dev;
     }
 #if MYNEWT_VAL(ENC_FLASH_DEV)
     if (id == 1) {
