@@ -20,6 +20,7 @@
 
 #include "bsp/bsp.h"
 #include "os/mynewt.h"
+#include "mynewt_cm.h"
 
 #include <hal/hal_bsp.h>
 #include <hal/hal_flash_int.h>
@@ -187,16 +188,16 @@ const struct stm32_eth_cfg os_bsp_eth0_cfg = {
 /* FIXME */
 static const struct hal_bsp_mem_dump dump_cfg[] = {
     [0] = {
-        .hbmd_start = &_ram_start,
+        .hbmd_start = _ram_start,
         .hbmd_size = RAM_SIZE,
     },
     [1] = {
-        .hbmd_start = &_dtcmram_start,
-        .hbmd_size = DTCMRAM_SIZE,
+        .hbmd_start = _dtcm_start,
+        .hbmd_size = DTCM_SIZE,
     },
     [2] = {
-        .hbmd_start = &_itcmram_start,
-        .hbmd_size = ITCMRAM_SIZE,
+        .hbmd_start = _itcm_start,
+        .hbmd_size = ITCM_SIZE,
     },
 };
 
@@ -229,6 +230,7 @@ hal_bsp_init(void)
 void
 hal_bsp_deinit(void)
 {
+    Cortex_DisableAll();
 }
 
 /**
