@@ -54,7 +54,7 @@ hal_bsp_flash_dev(uint8_t id)
     if (id != 0) {
         return NULL;
     }
-    return &nrf52k_flash_dev;
+    return &nrf_flash_dev;
 }
 
 const struct hal_bsp_mem_dump *
