@@ -21,6 +21,8 @@
 #define _HW_DRIVERS_IPC_NRF5340_H
 
 #include <stdint.h>
+#include <stdbool.h>
+#include <os/os.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -71,8 +73,26 @@ void ipc_nrf5340_recv(int channel, ipc_nrf5340_recv_cb cb, void *user_data);
 int ipc_nrf5340_send(int channel, const void *data, uint16_t len);
 
 /**
- * Reads data from IPC ring buffer to specified flat buffer. Should be used only
- * from ipc_nrf5340_recv_cb context.
+ * Sends data over specified IPC channel. IPC uses ring buffer for data passing.
+ * If IPC_NRF5340_BLOCKING_WRITE is not enable and there is not enough space to
+ * store data SYS_ENOMEM error is returned.
+ *
+ * @param channel     IPC channel number to send on
+ * @param data        Data to be sent over IPC. If this is NULL only signal is
+ *                    sent
+ * @param len         Data length
+ * @param last        If this is the last send, so other side can be notified
+ *
+ * @return            0 on success and negative error on failure
+ */
+int ipc_nrf5340_write(int channel, const void *data, uint16_t len, bool last);
+
+/**
+ * Reads data from IPC ring buffer to specified flat buffer.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
  *
  * @param channel     IPC channel number to read from
  * @param buf         Buffer to read data to
@@ -83,8 +103,11 @@ int ipc_nrf5340_send(int channel, const void *data, uint16_t len);
 uint16_t ipc_nrf5340_read(int channel, void *buf, uint16_t len);
 
 /**
- * Reads data from IPC ring buffer to specified mbuf. Should be used only
- * from ipc_nrf5340_recv_cb context.
+ * Reads data from IPC ring buffer to specified mbuf.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
  *
  * @param channel     IPC channel number to read from
  * @param om          mbuf to read data to
@@ -95,8 +118,13 @@ uint16_t ipc_nrf5340_read(int channel, void *buf, uint16_t len);
 uint16_t ipc_nrf5340_read_om(int channel, struct os_mbuf *om, uint16_t len);
 
 /**
- * Returns number of data bytes available in IPC ring buffer. Should be used
- * only from ipc_nrf5340_recv_cb context.
+ * Returns number of data bytes available in IPC ring buffer.
+ *
+ * Note: use ipc_nrf5340_data_available_get() instead
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
  *
  * @param channel     IPC channel number
  *
@@ -106,7 +134,12 @@ uint16_t ipc_nrf5340_available(int channel);
 
 /**
  * Returns number of continuous data bytes available in IPC ring buffer with
- * pointer to that data. Should be used only from ipc_nrf5340_recv_cb context.
+ * pointer to that data.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
+ *
  *
  * @param channel     IPC channel number
  * @param dptr        Pointer to data buffer
@@ -116,8 +149,37 @@ uint16_t ipc_nrf5340_available(int channel);
 uint16_t ipc_nrf5340_available_buf(int channel, void **dptr);
 
 /**
- * Consumes data from IPC ring buffer without copying. Should be used only
- * from ipc_nrf5340_recv_cb context.
+ * Returns number of data bytes available in IPC ring buffer for reading.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
+ *
+ * @param channel     IPC channel number
+ *
+ * @return            Number of bytes available in IPC ring buffer
+ */
+uint16_t ipc_nrf5340_data_available_get(int channel);
+
+/**
+ * Returns number of free data bytes available in IPC ring buffer for writing.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
+ *
+ * @param channel     IPC channel number
+ *
+ * @return            Number of bytes available in IPC ring buffer
+ */
+uint16_t ipc_nrf5340_data_free_get(int channel);
+
+/**
+ * Consumes data from IPC ring buffer without copying.
+ *
+ * Note: this function does not use any kind of locking so it's up to caller
+ *       to make sure it's not used during write from other context as it may
+ *       yield incorrect results.
  *
  * @param channel     IPC channel number to consume from
  * @param len         Number of bytes to consume
@@ -135,6 +197,22 @@ uint16_t ipc_nrf5340_consume(int channel, uint16_t len);
  */
 void ipc_nrf5340_set_net_core_restart_cb(void (*on_restart)(void));
 
+#if MYNEWT_VAL(MCU_NET_CORE)
+/**
+ * Get embedded netcore image and its size.
+ *
+ * @param size        Size of embedded image in bytes.
+ *
+ * @return            Pointer to image, NULL if not present
+ */
+const void *ipc_nrf5340_net_image_get(uint32_t *size);
+#endif
+
+
+#if MYNEWT_PKG_apache_mynewt_nimble__nimble_transport_common_hci_ipc
+volatile struct hci_ipc_shm *ipc_nrf5340_hci_shm_get(void);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
