@@ -32,6 +32,9 @@
 #include "modlog/modlog.h"
 #include "stats/stats.h"
 #include <syscfg/syscfg.h>
+#if MYNEWT_VAL(BUS_DRIVER_PRESENT)
+#include <bus/drivers/i2c_common.h>
+#endif
 
 /* Define the stats section and records */
 STATS_SECT_START(mpu6050_stat_section)
@@ -104,6 +107,55 @@ mpu6050_write8(struct sensor_itf *itf, uint8_t reg, uint32_t value)
     return rc;
 }
 
+/**
+ * Writes two bytes to the specified register
+ *
+ * @param The sensor interface
+ * @param The register address to write to
+ * @param The value to write
+ *
+ * @return 0 on success, non-zero error on failure.
+ */
+int
+mpu6050_write16(struct sensor_itf *itf, uint8_t reg, uint16_t value)
+{
+    int rc;
+    uint8_t payload[3] = {
+        reg,
+        (uint8_t)(value >> 8),
+        (uint8_t)value,
+    };
+
+#if MYNEWT_VAL(BUS_DRIVER_PRESENT)
+    rc = bus_node_simple_write(itf->si_dev, payload, 3);
+#else
+    struct hal_i2c_master_data data_struct = {
+        .address = itf->si_addr,
+        .len = 3,
+        .buffer = payload
+    };
+
+    rc = sensor_itf_lock(itf, MYNEWT_VAL(MPU6050_ITF_LOCK_TMO));
+    if (rc) {
+        return rc;
+    }
+
+    rc = i2cn_master_write(itf->si_num, &data_struct, OS_TICKS_PER_SEC / 10, 1,
+                           MYNEWT_VAL(MPU6050_I2C_RETRIES));
+
+    if (rc) {
+        MPU6050_LOG_ERROR(
+            "Failed to write to 0x%02X:0x%02X with value 0x%02lX\n",
+            itf->si_addr, reg, value);
+        STATS_INC(g_mpu6050stats, read_errors);
+    }
+
+    sensor_itf_unlock(itf);
+#endif
+
+    return rc;
+}
+
 /**
  * Reads a single byte from the specified register
  *
@@ -159,6 +211,62 @@ mpu6050_read8(struct sensor_itf *itf, uint8_t reg, uint8_t *value)
     return rc;
 }
 
+/**
+ * Reads 2 bytes from the specified register
+ *
+ * @param The sensor interface
+ * @param The register address to read from
+ * @param Pointer to where the register value should be written
+ *
+ * @return 0 on success, non-zero error on failure.
+ */
+int
+mpu6050_read16(struct sensor_itf *itf, uint8_t reg, uint8_t *buffer)
+{
+    int rc;
+
+#if MYNEWT_VAL(BUS_DRIVER_PRESENT)
+    rc = bus_node_simple_write_read_transact(itf->si_dev, &reg, 1, buffer, 2);
+#else
+    struct hal_i2c_master_data data_struct = {
+        .address = itf->si_addr,
+        .len = 1,
+        .buffer = &reg
+    };
+
+    rc = sensor_itf_lock(itf, MYNEWT_VAL(MPU6050_ITF_LOCK_TMO));
+    if (rc) {
+        return rc;
+    }
+
+    /* Register write */
+    rc = i2cn_master_write(itf->si_num, &data_struct, OS_TICKS_PER_SEC / 10, 0,
+                           MYNEWT_VAL(MPU6050_I2C_RETRIES));
+    if (rc) {
+        MPU6050_LOG_ERROR("I2C access failed at address 0x%02X\n",
+                          itf->si_addr);
+        STATS_INC(g_mpu6050stats, write_errors);
+        return rc;
+    }
+
+    /* Read two bytes back */
+    data_struct.len = 2;
+    data_struct.buffer = buffer;
+    rc = i2cn_master_read(itf->si_num, &data_struct, OS_TICKS_PER_SEC / 10, 1,
+                          MYNEWT_VAL(MPU6050_I2C_RETRIES));
+
+    if (rc) {
+        MPU6050_LOG_ERROR("Failed to read from 0x%02X:0x%02X\n",
+                          itf->si_addr, reg);
+        STATS_INC(g_mpu6050stats, read_errors);
+    }
+
+    sensor_itf_unlock(itf);
+#endif
+
+    return rc;
+}
+
 /**
  * Reads a six bytes from the specified register
  *
@@ -391,6 +499,138 @@ mpu6050_config_interrupt(struct sensor_itf *itf, uint8_t cfg)
     return mpu6050_write8(itf, MPU6050_INT_PIN_CFG, reg);
 }
 
+int
+mpu6050_set_x_accel_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_XA_OFFS_H, offset);
+}
+
+int
+mpu6050_get_x_accel_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_XA_OFFS_H, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
+int
+mpu6050_set_y_accel_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_YA_OFFS_H, offset);
+}
+
+int
+mpu6050_get_y_accel_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_YA_OFFS_H, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
+int
+mpu6050_set_z_accel_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_ZA_OFFS_H, offset);
+}
+
+int
+mpu6050_get_z_accel_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_ZA_OFFS_H, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
+int
+mpu6050_set_x_gyro_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_XG_OFFS_USRH, offset);
+}
+
+int
+mpu6050_get_x_gyro_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_XG_OFFS_USRH, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
+int
+mpu6050_set_y_gyro_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_YG_OFFS_USRH, offset);
+}
+
+int
+mpu6050_get_y_gyro_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_YG_OFFS_USRH, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
+int
+mpu6050_set_z_gyro_offset(struct sensor_itf *itf, int16_t offset)
+{
+    return mpu6050_write16(itf, MPU6050_RA_ZG_OFFS_USRH, offset);
+}
+
+int
+mpu6050_get_z_gyro_offset(struct sensor_itf *itf, int16_t *offset)
+{
+    uint8_t reg[2];
+    int rc;
+
+    rc = mpu6050_read16(itf, MPU6050_RA_ZG_OFFS_USRH, reg);
+    if (rc) {
+        return rc;
+    }
+
+    *offset = (((int16_t)reg[0]) << 8) | reg[1];
+
+    return 0;
+}
+
 /**
  * Expects to be called back through os_dev_create().
  *
@@ -447,6 +687,44 @@ mpu6050_init(struct os_dev *dev, void *arg)
     return sensor_mgr_register(sensor);
 }
 
+int
+mpu6050_set_offsets(struct mpu6050 *mpu, struct mpu6050_cfg *cfg)
+{
+    int rc = 0;
+    struct sensor_itf *itf;
+
+    itf = SENSOR_GET_ITF(&(mpu->sensor));
+
+    /* Set offsets */
+    rc = mpu6050_set_x_accel_offset(itf, cfg->accel_offset[0]);
+    if (rc) {
+        return rc;
+    }
+
+    rc = mpu6050_set_y_accel_offset(itf, cfg->accel_offset[1]);
+    if (rc) {
+        return rc;
+    }
+
+    rc = mpu6050_set_z_accel_offset(itf, cfg->accel_offset[2]);
+    if (rc) {
+        return rc;
+    }
+
+    rc = mpu6050_set_x_gyro_offset(itf, cfg->gyro_offset[0]);
+    if (rc) {
+        return rc;
+    }
+
+    rc = mpu6050_set_y_gyro_offset(itf, cfg->gyro_offset[1]);
+    if (rc) {
+        return rc;
+    }
+
+    rc = mpu6050_set_z_gyro_offset(itf, cfg->gyro_offset[2]);
+    return rc;
+}
+
 int
 mpu6050_config(struct mpu6050 *mpu, struct mpu6050_cfg *cfg)
 {
@@ -590,10 +868,16 @@ mpu6050_sensor_read(struct sensor *sensor, sensor_type_t type,
         databuf.sad.sad_z = (z / lsb) * STANDARD_ACCEL_GRAVITY;
         databuf.sad.sad_z_is_valid = 1;
 
-        rc = data_func(sensor, data_arg, &databuf.sad,
-                SENSOR_TYPE_ACCELEROMETER);
-        if (rc) {
-            return rc;
+        if (data_func != NULL) {
+            rc = data_func(sensor, data_arg, &databuf.sad,
+                           SENSOR_TYPE_ACCELEROMETER);
+            if (rc) {
+                return rc;
+            }
+        } else {
+            struct sensor_accel_data *sad = data_arg;
+            memcpy(sad, &databuf.sad, sizeof(struct sensor_accel_data));
+            return 0;
         }
     }
 
@@ -632,15 +916,34 @@ mpu6050_sensor_read(struct sensor *sensor, sensor_type_t type,
         databuf.sgd.sgd_z = z / lsb;
         databuf.sgd.sgd_z_is_valid = 1;
 
-        rc = data_func(sensor, data_arg, &databuf.sgd, SENSOR_TYPE_GYROSCOPE);
-        if (rc) {
-            return rc;
+        if (data_func != NULL) {
+            rc = data_func(sensor, data_arg, &databuf.sgd, SENSOR_TYPE_GYROSCOPE);
+            if (rc) {
+                return rc;
+            }
+        } else {
+            struct sensor_gyro_data *sgd = data_arg;
+            memcpy(sgd, &databuf.sgd, sizeof(struct sensor_gyro_data));
         }
     }
 
     return 0;
 }
 
+int
+mpu6050_get_accel(struct mpu6050 *mpu6050, struct sensor_accel_data *sad)
+{
+    return mpu6050_sensor_read(&mpu6050->sensor, SENSOR_TYPE_ACCELEROMETER,
+                                 NULL, sad, OS_TIMEOUT_NEVER);
+}
+
+int
+mpu6050_get_gyro(struct mpu6050 *mpu6050, struct sensor_gyro_data *sgd)
+{
+    return mpu6050_sensor_read(&mpu6050->sensor, SENSOR_TYPE_GYROSCOPE,
+                                 NULL, sgd, OS_TIMEOUT_NEVER);
+}
+
 static int
 mpu6050_sensor_get_config(struct sensor *sensor, sensor_type_t type,
         struct sensor_cfg *cfg)
