@@ -87,6 +87,32 @@ extern const int qspi_flash_config_array_size;
 
 const struct qspi_flash_config *da1469x_qspi_get_config(void);
 
+/**
+ * Calculate the OS tick parameters.
+ *
+ * @param cycles_per_sec Input frequency of timer generating OS ticks
+ */
+void hal_os_tick_calc_params(uint32_t cycles_per_sec);
+
+/**
+ * Configure GPIO using a single value.
+ *
+ * @param pin GPIO ID
+ * @param raw_mode Combined mode / I/O properties value
+ *                 Mode: Selected feed in the GPIO matrix (see MCU_GPIO_FUNC_*)
+ *                 I/O propeties: Input [bare/PU/PD] or output [PP/OD] (see MCU_GPIO_MODE_*)
+ */
+void mcu_gpio_set_pin_function_raw(int pin, uint32_t raw_mode);
+
+/**
+ * Query GPIO mode as a single value.
+ *
+ * @param pin GPIO ID
+ *
+ * @return Combined mode / I/O properties value
+ */
+uint32_t mcu_gpio_get_pin_function_raw(int pin);
+
 #ifdef __cplusplus
 }
 #endif
