@@ -89,7 +89,8 @@ enum da1469x_rtc_div_denom_sel {
 static uint32_t g_mcu_clock_rcx_freq;
 static uint32_t g_mcu_clock_rc32k_freq;
 static uint32_t g_mcu_clock_rc32m_freq = RC32M_FREQ;
-static uint32_t g_mcu_clock_xtal32k_freq;
+/* 32 kHz xtal freq, with nominal value until calibration */
+static uint32_t g_mcu_clock_xtal32k_freq = XTAL32K_FREQ;
 
 uint32_t SystemCoreClock = RC32M_FREQ;
 
