@@ -10,16 +10,12 @@
 #include <stdint.h>
 #include "nrf.h"
 
-#define NVIC_NUM_VECTORS      (NVIC_USER_IRQ_OFFSET + 240)   /* CORE + MCU Peripherals */
+#define NVIC_NUM_VECTORS      (NVIC_USER_IRQ_OFFSET + 64)   /* CORE + MCU Peripherals */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-void NVIC_Relocate(void);
-void NVIC_SetVector(IRQn_Type IRQn, uint32_t vector);
-uint32_t NVIC_GetVector(IRQn_Type IRQn);
-
 #ifdef __cplusplus
 }
 #endif
