@@ -18,7 +18,8 @@
  */
 
 #include <assert.h>
-#include "os/mynewt.h"
+#include <os/mynewt.h>
+#include <stm32_common/mcu.h>
 #include <hal/hal_os_tick.h>
 
 #if MYNEWT_VAL(OS_TICKS_USE_RTC)
@@ -26,33 +27,22 @@
 #include <datetime/datetime.h>
 #endif
 
+#if MYNEWT_VAL(STM32_WFI_FROM_RAM)
+__attribute__((section(".text_ram"),noinline)) void
+stm32_wfi_from_ram(void)
+{
+    __ASM volatile ("wfi");
+}
+#endif
+
 /*
  * ST's MCUs seems to have problem with accessing AHB interface from SWD during SLEEP.
  * This makes it almost impossible to use with SEGGER SystemView, therefore when OS_SYSVIEW
  * is defined __WFI will become a loop waiting for pending interrupts.
  */
 #if MYNEWT_VAL(OS_SYSVIEW)
-#undef __WFI
-#define __WFI() do { } while ((SCB->ICSR & (SCB_ICSR_ISRPENDING_Msk | SCB_ICSR_PENDSTSET_Msk)) == 0)
-#else
-/*
- * Errata for STM32F405, STM32F407, STM32F415, STM32F417.
- * When WFI instruction is placed at address like 0x080xxxx4
- * (also seen for addresses ending with xxx2). System may
- * crash.
- * __WFI function places WFI instruction at address ending with x0 or x8
- * for affected MCUs.
- */
-#if defined(STM32F405xx) || defined(STM32F407xx) || \
-    defined(STM32F415xx) || defined(STM32F417xx)
-#undef __WFI
-__attribute__((aligned(8), naked)) void static
-__WFI(void)
-{
-     __ASM volatile("wfi\n"
-                    "bx lr");
-}
-#endif
+#undef STM32_WFI
+#define STM32_WFI() do { } while ((SCB->ICSR & (SCB_ICSR_ISRPENDING_Msk | SCB_ICSR_PENDSTSET_Msk)) == 0)
 #endif
 
 #if MYNEWT_VAL(OS_TICKS_USE_RTC)
@@ -219,7 +209,7 @@ os_tick_idle(os_time_t ticks)
     }
 
     __DSB();
-    __WFI();
+    STM32_WFI();
 
     if (ticks > 0) {
         rtc_update_time();
@@ -316,6 +306,12 @@ os_tick_init(uint32_t os_ticks_per_sec, int prio)
         .PeriphClockSelection = RCC_PERIPHCLK_RTC,
         .RTCClockSelection = RCC_RTCCLKSOURCE_LSE,
     };
+    /*
+     * Disable SysTick so only one interrupt advances time.
+     * this is needed when bootloader enabled SysTick
+     */
+    SysTick->CTRL = 0;
+
     HAL_RCCEx_PeriphCLKConfig(&clock_init);
 
     /* Set the system tick priority. */
@@ -324,6 +320,8 @@ os_tick_init(uint32_t os_ticks_per_sec, int prio)
 
 #ifdef __HAL_RCC_RTCAPB_CLK_ENABLE
     __HAL_RCC_RTCAPB_CLK_ENABLE();
+#elif defined(__HAL_RCC_RTC_CLK_ENABLE)
+    __HAL_RCC_RTC_CLK_ENABLE();
 #endif
 #ifdef __HAL_RCC_RTCAPB_CLKAM_ENABLE
     __HAL_RCC_RTCAPB_CLKAM_ENABLE();
@@ -387,7 +385,7 @@ os_tick_idle(os_time_t ticks)
 {
     OS_ASSERT_CRITICAL();
     __DSB();
-    __WFI();
+    STM32_WFI();
 }
 
 void
