@@ -108,6 +108,8 @@ os_tick_idle(os_time_t ticks)
          */
         stm32_os_tick_update_rtc();
     }
+    /* Disable alarm, enable tick interrupt. */
+    RTC->CRH = RTC_CRH_SECIE_Msk;
 }
 
 void
@@ -118,6 +120,7 @@ os_tick_init(uint32_t os_ticks_per_sec, int prio)
         .PeriphClockSelection = RCC_PERIPHCLK_RTC,
         .RTCClockSelection = RCC_RTCCLKSOURCE_LSE,
     };
+    SysTick->CTRL = 0;
 
     HAL_RCCEx_PeriphCLKConfig(&clock_init);
     __HAL_RCC_RTC_ENABLE();
