@@ -18,21 +18,15 @@
  */
 
 #include "os/mynewt.h"
+#include "mynewt_cm.h"
 #include "mcu/stm32_hal.h"
 #include <hal/hal_system.h>
 
-extern char __vector_tbl_reloc__[];
-
-/*
- * XXX BSP specific
- */
 void SystemClock_Config(void);
 
 void
 hal_system_init(void)
 {
-    SCB->VTOR = (uint32_t)&__vector_tbl_reloc__;
-
     /* Configure System Clock */
     SystemClock_Config();
 
@@ -50,4 +44,3 @@ hal_system_init(void)
         __HAL_FLASH_INSTRUCTION_CACHE_ENABLE();
     }
 }
-
