@@ -22,10 +22,6 @@ extern uint32_t __isr_vector_end[];
 extern "C" {
 #endif
 
-void NVIC_Relocate(void);
-void NVIC_SetVector(IRQn_Type IRQn, uint32_t vector);
-uint32_t NVIC_GetVector(IRQn_Type IRQn);
-
 #ifdef __cplusplus
 }
 #endif
