@@ -24,6 +24,10 @@
 #include <xc.h>
 #include "mcu/pic32.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* CPU status register */
 typedef uint32_t os_sr_t;
 
@@ -50,6 +54,10 @@ os_arch_in_isr(void)
     return (_CP0_GET_STATUS() & (_CP0_STATUS_EXL_MASK | _CP0_STATUS_IPL_MASK)) ? 1 : 0;
 }
 
+#ifdef __cplusplus
+}
+#endif
+
 /* Include common arch definitions and APIs */
 #include "os/arch/common.h"
 
