@@ -36,6 +36,10 @@ void __assert_func(const char *file, int line, const char *func, const char *e)
 typedef void (*coredump_cb_t)(void *tf);
 #endif
 
+#if MYNEWT_VAL(OS_DEFAULT_IRQ_CB)
+void os_default_irq_cb(void);
+#endif
+
 #if MYNEWT_VAL(OS_CRASH_FILE_LINE)
 #define OS_CRASH() (HAL_DEBUG_BREAK(), __assert_func(__FILE__, __LINE__, NULL, NULL))
 #else
