@@ -25,5 +25,5 @@ TEST_CASE_TASK(os_mutex_test_basic)
     os_mutex_init(&g_mutex1);
     taskpool_alloc_assert(mutex_test_basic_handler,
                           MYNEWT_VAL(OS_MAIN_TASK_PRIO) + 2);
-    taskpool_wait_assert(200);
+    taskpool_wait_assert(OS_TICKS_PER_SEC * 4);
 }
