@@ -237,7 +237,7 @@ os_arch_os_init(void)
         err = OS_OK;
 
         /* Drop priority for all interrupts */
-        for (i = 0; i < sizeof(NVIC->IPR); i++) {
+        for (i = 0; i < ARRAY_SIZE(NVIC->IPR); i++) {
             NVIC->IPR[i] = -1;
         }
 
