@@ -4,6 +4,7 @@
 
 #include <stdio.h>
 #include <stdint.h>
+#include <limits.h>
 
 int sprintf(char *buffer, const char *format, ...)
 {
@@ -11,7 +12,7 @@ int sprintf(char *buffer, const char *format, ...)
 	int rv;
 
 	va_start(ap, format);
-	rv = vsnprintf(buffer, SIZE_MAX/2, format, ap);
+	rv = vsnprintf(buffer, INT_MAX/2, format, ap);
 	va_end(ap);
 
 	return rv;
