@@ -42,6 +42,11 @@ extern "C" {
  */
 #define OSDP_FLAG_INSTALL_MODE         0x00020000
 
+/**
+ * @brief When set, the PD will not set up secure mode capability.
+ */
+#define OSDP_FLAG_NON_SECURE_MODE      0x00040000
+
 /**
  * @brief Various PD capability function codes.
  */
