@@ -77,6 +77,46 @@ struct log_storage_info {
 };
 #endif
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+
+#define LOG_TRAILER_LEN_SIZE 2
+
+/** @typedef log_trailer_free_func_t
+ * @brief Callback that frees the trailer buffer, to be called by user of the
+ * library once append returns, either successfully or unsuccessfully
+ *
+ * @param log                 The log the trailer is being appended to
+ * @param om                  mbuf pointer to be freed
+ * @param arg                 Argument to be passed to the trailer handler
+ *
+ * @return                    0 on success, non-zero on failure
+ */
+typedef int log_trailer_free_func_t(struct log *log, struct os_mbuf *om, void *arg);
+
+/** @typedef log_trailer_get_data_func_t
+ * @brief Callback that is executed each time the corresponding log entry is
+ * appended to
+ *
+ * @param log                 The log the trailer needs to be appended to
+ * @param om                  mbuf pointer to be set to mbuf which contains
+ *                            trailer data
+ * @param arg                 Argument to be passed to the trailer handler
+ *
+ * @return                    0 on success, non-zero on failure
+ */
+typedef int log_trailer_get_data_func_t(struct log *log, struct os_mbuf **om, void *arg);
+
+/** @typedef log_trailer_reset_data_func_t
+ * @brief Callback used to reset trailer data per log
+ *
+ * @param log                 The log the trailer is to be read from
+ * @param arg                 Argument to be passed to the trailer handler
+ *
+ * @return                    0 on success, non-zero on failure.
+ */
+typedef int log_trailer_reset_data_func_t(struct log *log, void *arg);
+#endif
+
 typedef int (*log_walk_func_t)(struct log *, struct log_offset *log_offset,
         const void *dptr, uint16_t len);
 
@@ -99,6 +139,7 @@ typedef int (*lh_append_mbuf_body_func_t)(struct log *log,
 typedef int (*lh_walk_func_t)(struct log *,
         log_walk_func_t walk_func, struct log_offset *log_offset);
 typedef int (*lh_flush_func_t)(struct log *);
+typedef uint16_t (*lh_read_entry_len_func_t)(struct log *log, const void *dptr);
 #if MYNEWT_VAL(LOG_STORAGE_INFO)
 typedef int (*lh_storage_info_func_t)(struct log *, struct log_storage_info *);
 #endif
@@ -118,6 +159,7 @@ struct log_handler {
     lh_walk_func_t log_walk;
     lh_walk_func_t log_walk_sector;
     lh_flush_func_t log_flush;
+    lh_read_entry_len_func_t log_read_entry_len;
 #if MYNEWT_VAL(LOG_STORAGE_INFO)
     lh_storage_info_func_t log_storage_info;
 #endif
@@ -131,8 +173,9 @@ struct log_handler {
 /* Image hash length to be looged */
 #define LOG_IMG_HASHLEN 4
 
-/* Flags used to indicate type of data in reserved payload*/
+/* Flags used to indicate type of data in reserved payload */
 #define LOG_FLAGS_IMG_HASH (1 << 0)
+#define LOG_FLAGS_TRAILER  (1 << 1)
 
 #if MYNEWT_VAL(LOG_VERSION) == 3
 struct log_entry_hdr {
@@ -191,6 +234,7 @@ struct log_entry_hdr {
 STATS_SECT_START(logs)
     STATS_SECT_ENTRY(writes)
     STATS_SECT_ENTRY(drops)
+    STATS_SECT_ENTRY(regerr)
     STATS_SECT_ENTRY(errs)
     STATS_SECT_ENTRY(lost)
     STATS_SECT_ENTRY(too_long)
@@ -203,6 +247,20 @@ STATS_SECT_END
 #define LOG_STATS_INCN(log, name, cnt)
 #endif
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+/* Trailer support callbacks */
+struct log_trailer_handler {
+    /* Frees the trailer buffer */
+    log_trailer_free_func_t *lth_trailer_free;
+    /* Trailer append callback used to append trailer to the log entry */
+    log_trailer_get_data_func_t *lth_trailer_get_data;
+    /* Trailer reset data callback used to reset the trailer data
+     * per log which is defined by the application registering these callbacks
+     */
+    log_trailer_reset_data_func_t *lth_trailer_reset_data;
+};
+#endif
+
 struct log {
     const char *l_name;
     const struct log_handler *l_log;
@@ -218,6 +276,23 @@ struct log {
 #if MYNEWT_VAL(LOG_STATS)
     STATS_SECT_DECL(logs) l_stats;
 #endif
+#if MYNEWT_VAL(LOG_INIT_CB)
+    /* Custom log init callback to be called by the last hdr
+     * read function to read custom data from log entries
+     * at init
+     */
+    log_walk_func_t l_init_cb;
+#endif
+
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    /* Log trailer support */
+    /* Void argument for callbacks registeration */
+    void *l_tr_arg;
+    /* Trailer mbuf */
+    struct os_mbuf *l_tr_om;
+    /* Trailer handler with callbacks */
+    struct log_trailer_handler *l_th;
+#endif
 };
 
 /* Log system level functions (for all logs.) */
@@ -513,6 +588,134 @@ void log_printf(struct log *log, uint8_t module, uint8_t level,
 int log_read(struct log *log, const void *dptr, void *buf, uint16_t off,
         uint16_t len);
 
+#if MYNEWT_VAL(LOG_INIT_CB)
+/**
+ * Reads entry length from the specified log.
+ *
+ * @return                      The number of bytes of entry length; 0 on failure.
+ */
+uint16_t
+log_read_entry_len(struct log *log, const void *dptr);
+
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+
+/**
+ * @brief                Read log trailer of a specific entry
+ *
+ * @param log            The log to read trailer data from
+ * @param dptr           Data pointer to the log entry
+ * @param buf            Pointer to the buffer to read the trailer into
+ *
+ * @return 0 on success; nonzero on failure.
+ */
+uint16_t
+log_read_trailer(struct log *log, const void *dptr, uint8_t *buf);
+
+/**
+ * @brief                Read log trailer length of a specific entry
+ *
+ * @param log            The log to read trailer data from
+ * @param dptr           Data pointer to the log entry
+ *
+ * @return length of the trailer for a specific log entry;
+ */
+uint16_t log_read_trailer_len(struct log *log, const void *dptr);
+
+/**Add commentMore actions
+ * @brief Returns trailer data in an mbuf specified by the caller
+ *
+ * @param log                   The log to append to
+ * @param om                    mbuf pointer to be set to buffer which contains
+ *                              trailer data
+ * @param arg                   Argument to be passed to the trailer handler
+ *
+ * @return                      0 on success; nonzero on failure.
+ */
+static inline int
+log_trailer_get_data(struct log *log, struct os_mbuf **om, void *arg)
+{
+    if (log->l_th && log->l_th->lth_trailer_get_data) {
+        return log->l_th->lth_trailer_get_data(log, om, arg);
+    }
+    return SYS_ENOTSUP;
+}
+
+/**
+ * @brief Callback that frees the trailer buffer, to be called by user of the library
+ * once append returns, either successfully or unsuccessfully
+ *
+ * @param log                   The log the trailer is being appended to
+ * @param om                    mbuf pointer to be freed
+ * @param arg                   Argument to be passed to the trailer handler
+ *
+ * @return                      0 on success; nonzero on failure.
+ */
+static inline int
+log_trailer_free(struct log *log, struct os_mbuf *om, void *arg)
+{
+    if (log->l_th && log->l_th->lth_trailer_free) {
+        return log->l_th->lth_trailer_free(log, om, arg);
+    }
+    return SYS_ENOTSUP;
+}
+
+/**
+ * @brief Resets the trailer data in the log, calling user callback
+ *
+ * @param log                   The log to reset.
+ * @param arg                   Argument to be passed to the trailer handler
+ *
+ * @return                      0 on success; nonzero on failure.
+ */
+static inline int
+log_trailer_reset_data(struct log *log, void *arg)
+{
+    if (log->l_th && log->l_th->lth_trailer_reset_data) {
+        return log->l_th->lth_trailer_reset_data(log, arg);
+    }
+    return SYS_ENOTSUP;
+}
+
+/**
+ * @brief Register trailer callbacks, this is an experimental API
+ *        and may be changed/deprecated later. This needs to be
+ *        called before log_register() if the trailer data needs
+ *        to be initialized when the log gets registered.
+ *
+ * @param log            The log to read from.
+ * @param lth            The trailer handler to register.
+ * @param arg            Argument to be passed to the trailer handler
+ *
+ * @return 0 on success; nonzero on failure.
+ */
+static inline void
+log_trailer_cbs_register(struct log *log, struct log_trailer_handler *lth,
+                         void *arg)
+{
+    if (!lth || !log) {
+        return;
+    }
+
+    log->l_th = lth;
+    log->l_tr_arg = arg;
+}
+#endif
+
+/**
+ * @brief Register Log init callback to be called by log_read_last_hdr
+ * while reading the last log entry at init
+ *
+ * @param log                   The log to register.
+ * @param cb                    The callback to associate with the log.
+ *
+ */
+static inline void
+log_register_init_cb(struct log *log, log_walk_func_t cb)
+{
+    log->l_init_cb = cb;
+}
+#endif
+
 /**
  * @brief Reads a single log entry header.
  *
@@ -530,7 +733,7 @@ int log_read_hdr(struct log *log, const void *dptr, struct log_entry_hdr *hdr);
  * @brief Reads the header length
  *
  * @param hdr Ptr to the header
- * 
+ *
  * @return Length of the header
  */
 uint16_t
@@ -737,6 +940,21 @@ int log_set_watermark(struct log *log, uint32_t index);
 int
 log_fill_current_img_hash(struct log_entry_hdr *hdr);
 
+/**
+ * @brief Reads the final log entry's header and processes trailer if the flag
+ * indicates so from the specified log only if the log supports trailers
+ * and mynewt val LOG_FLAGS_TRAILER is 1
+ *
+ * @param log            The log to read from.
+ * @param out_hdr        On success, the last entry header gets written
+ *                       here.
+ * @param trailer_exists Pointer to a boolean
+ *
+ * @return 0 on success; nonzero on failure.
+ */
+int log_read_last_hdr_trailer(struct log *log, struct log_entry_hdr *out_hdr,
+                              bool *trailer_exists);
+
 /* Handler exports */
 #if MYNEWT_VAL(LOG_CONSOLE)
 extern const struct log_handler log_console_handler;
