@@ -22,7 +22,7 @@
 TEST_CASE_SELF(log_test_case_fcb_printf)
 {
     struct fcb_log fcb_log;
-    struct log log;
+    struct log log = {0};
     char *str;
     int i;
 
