@@ -50,37 +50,14 @@ static struct log_module_entry g_log_module_list[
 static int g_log_module_count;
 static uint8_t log_written;
 
-#if MYNEWT_VAL(LOG_CLI)
-int shell_log_dump_cmd(int, char **);
-struct shell_cmd g_shell_log_cmd = {
-    .sc_cmd = "log",
-    .sc_cmd_func = shell_log_dump_cmd
-};
-
-#if MYNEWT_VAL(LOG_FCB_SLOT1)
-int shell_log_slot1_cmd(int, char **);
-struct shell_cmd g_shell_slot1_cmd = {
-    .sc_cmd = "slot1",
-    .sc_cmd_func = shell_log_slot1_cmd,
-};
-#endif
-
-#if MYNEWT_VAL(LOG_STORAGE_INFO)
-int shell_log_storage_cmd(int, char **);
-struct shell_cmd g_shell_storage_cmd = {
-    .sc_cmd = "log-storage",
-    .sc_cmd_func = shell_log_storage_cmd,
-};
-#endif
-#endif
-
 #if MYNEWT_VAL(LOG_STATS)
 STATS_NAME_START(logs)
-  STATS_NAME(logs, writes)
-  STATS_NAME(logs, drops)
-  STATS_NAME(logs, errs)
-  STATS_NAME(logs, lost)
-  STATS_NAME(logs, too_long)
+    STATS_NAME(logs, writes)
+    STATS_NAME(logs, drops)
+    STATS_NAME(logs, regerr)
+    STATS_NAME(logs, errs)
+    STATS_NAME(logs, lost)
+    STATS_NAME(logs, too_long)
 STATS_NAME_END(logs)
 #endif
 
@@ -148,15 +125,6 @@ log_init(void)
 #if MYNEWT_VAL(LOG_GLOBAL_IDX)
     g_log_info.li_next_index = 0;
 #endif
-#if MYNEWT_VAL(LOG_CLI)
-    shell_cmd_register(&g_shell_log_cmd);
-#if MYNEWT_VAL(LOG_FCB_SLOT1)
-    shell_cmd_register(&g_shell_slot1_cmd);
-#endif
-#if MYNEWT_VAL(LOG_STORAGE_INFO)
-    shell_cmd_register(&g_shell_storage_cmd);
-#endif
-#endif
 
 #if MYNEWT_VAL(LOG_CONSOLE)
     log_console_init();
@@ -293,9 +261,81 @@ log_find(const char *name)
     return log;
 }
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+uint16_t
+log_read_trailer(struct log *log, const void *dptr, uint8_t *buf)
+{
+    int rc = 0;
+    uint16_t offset = 0;
+    uint16_t trailer_len = 0;
+
+    if (log->l_th) {
+        /* This reads log entry length without alignment */
+        offset = log_read_entry_len(log, dptr);
+        if (offset) {
+            rc = log_read(log, dptr, &trailer_len,
+                          offset - LOG_TRAILER_LEN_SIZE,
+                          LOG_TRAILER_LEN_SIZE);
+            if (rc == LOG_TRAILER_LEN_SIZE) {
+                offset -= LOG_TRAILER_LEN_SIZE;
+                rc = log_read(log, dptr, buf, offset - trailer_len,
+                              trailer_len);
+                if (rc != trailer_len) {
+                    /* Trailer read failed, return 0 length
+                     * buffer remains untouched
+                     */
+                    return 0;
+                }
+            }
+        } else {
+            /* Entry length is 0, no trailer buffer remains untouched */
+            return 0;
+        }
+    }
+
+    /* No trailer, return 0 length */
+    return trailer_len;
+}
+
+uint16_t
+log_read_trailer_len(struct log *log, const void *dptr)
+{
+    int rc = 0;
+    uint16_t offset = 0;
+    uint16_t trailer_len = 0;
+
+    if (log->l_th) {
+        /* This reads log entry length without alignment */
+        offset = log_read_entry_len(log, dptr);
+        if (offset) {
+            rc = log_read(log, dptr, &trailer_len,
+                          offset - LOG_TRAILER_LEN_SIZE,
+                          LOG_TRAILER_LEN_SIZE);
+            if (rc == LOG_TRAILER_LEN_SIZE) {
+                return trailer_len;
+            } else {
+                /* Trailer read failed, return 0 length */
+                return 0;
+            }
+        } else {
+            /* Entry length is 0, no trailer */
+            return 0;
+        }
+    }
+
+    return 0;
+}
+#endif /* MYNEWT_VAL(LOG_FLAGS_TRAILER) */
+
+/* Argument for header/trailer walks */
 struct log_read_hdr_arg {
     struct log_entry_hdr *hdr;
     int read_success;
+    /* This is needed if the init_cb is called to read the trailer data */
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    bool trailer_exists;
+    void *trailer_arg;
+#endif
 };
 
 static int
@@ -319,6 +359,13 @@ log_read_hdr_walk(struct log *log, struct log_offset *log_offset, const void *dp
         }
     }
 
+#if MYNEWT_VAL(LOG_INIT_CB)
+    if (log->l_init_cb) {
+        /* If the log has an init callback, call it with the header. */
+        log->l_init_cb(log, log_offset, dptr, len);
+    }
+#endif
+
     /* Abort the walk; only one header needed. */
     return 1;
 }
@@ -335,8 +382,8 @@ log_read_hdr_walk(struct log *log, struct log_offset *log_offset, const void *dp
 static int
 log_read_last_hdr(struct log *log, struct log_entry_hdr *out_hdr)
 {
-    struct log_read_hdr_arg arg;
-    struct log_offset log_offset;
+    struct log_read_hdr_arg arg = {0};
+    struct log_offset log_offset = {};
 
     arg.hdr = out_hdr;
     arg.read_success = 0;
@@ -347,6 +394,7 @@ log_read_last_hdr(struct log *log, struct log_entry_hdr *out_hdr)
     log_offset.lo_data_len = 0;
 
     log_walk(log, log_read_hdr_walk, &log_offset);
+
     if (!arg.read_success) {
         return -1;
     }
@@ -356,6 +404,9 @@ log_read_last_hdr(struct log *log, struct log_entry_hdr *out_hdr)
 
 /*
  * Associate an instantiation of a log with the logging infrastructure
+ * If trailer data needs to be read, the trailer callbacks should be
+ * registered before calling this function. They are set using
+ * log_trailer_cbs_register().
  */
 int
 log_register(const char *name, struct log *log, const struct log_handler *lh,
@@ -382,7 +433,6 @@ log_register(const char *name, struct log *log, const struct log_handler *lh,
 #endif
 
     if (!log_registered(log)) {
-        STAILQ_INSERT_TAIL(&g_log_list, log, l_next);
 #if MYNEWT_VAL(LOG_STATS)
         stats_init(STATS_HDR(log->l_stats),
                    STATS_SIZE_INIT_PARMS(log->l_stats, STATS_SIZE_32),
@@ -391,15 +441,6 @@ log_register(const char *name, struct log *log, const struct log_handler *lh,
 #endif
     }
 
-    /* Call registered handler now - log structure is set and put on list */
-    if (log->l_log->log_registered) {
-        rc = log->l_log->log_registered(log);
-        if (rc) {
-            STAILQ_REMOVE(&g_log_list, log, log, l_next);
-            return rc;
-        }
-    }
-
     /* If this is a persisted log, read the index from its most recent entry.
      * We need to ensure the index of all subseqently written entries is
      * monotonically increasing.
@@ -418,6 +459,21 @@ log_register(const char *name, struct log *log, const struct log_handler *lh,
             }
 #endif
             OS_EXIT_CRITICAL(sr);
+        } else {
+            LOG_STATS_INC(log, regerr);
+        }
+    }
+
+    if (!log_registered(log)) {
+        STAILQ_INSERT_TAIL(&g_log_list, log, l_next);
+    }
+
+    /* Call registered handler now - log structure is set and put on list */
+    if (log->l_log->log_registered) {
+        rc = log->l_log->log_registered(log);
+        if (rc) {
+            STAILQ_REMOVE(&g_log_list, log, log, l_next);
+            return rc;
         }
     }
 
@@ -490,6 +546,9 @@ log_append_prepare(struct log *log, uint8_t module, uint8_t level,
     int sr;
     struct os_timeval tv;
     uint32_t idx;
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    struct os_mbuf *om = NULL;
+#endif
 
     rc = 0;
 
@@ -565,6 +624,19 @@ log_append_prepare(struct log *log, uint8_t module, uint8_t level,
     }
 #endif
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    if (log->l_th) {
+        rc = log_trailer_get_data(log, &om, log->l_tr_arg);
+        if (!rc && om) {
+            ue->ue_flags |= LOG_FLAGS_TRAILER;
+            log->l_tr_om = om;
+            rc = 0;
+        } else {
+            rc = SYS_ENOMEM;
+        }
+    }
+#endif
+
 err:
     return (rc);
 }
@@ -619,8 +691,15 @@ log_append_typed(struct log *log, uint8_t module, uint8_t level, uint8_t etype,
 
     log_call_append_cb(log, hdr->ue_index);
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
+
     return (0);
 err:
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
     return (rc);
 }
 
@@ -635,24 +714,32 @@ log_append_body(struct log *log, uint8_t module, uint8_t level, uint8_t etype,
 
     rc = log_chk_max_entry_len(log, body_len);
     if (rc != OS_OK) {
-        return rc;
+        goto err;
     }
 
     rc = log_append_prepare(log, module, level, etype, &hdr);
     if (rc != 0) {
         LOG_STATS_INC(log, drops);
-        return rc;
+        goto err;
     }
 
     rc = log->l_log->log_append_body(log, &hdr, body, body_len);
     if (rc != 0) {
         LOG_STATS_INC(log, errs);
-        return rc;
+        goto err;
     }
 
     log_call_append_cb(log, hdr.ue_index);
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
     return 0;
+err:
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
+    return rc;
 }
 
 int
@@ -665,7 +752,7 @@ log_append_mbuf_typed_no_free(struct log *log, uint8_t module, uint8_t level,
     uint16_t hdr_len;
     int rc;
 
-    /* Remove a loyer of indirection for convenience. */
+    /* Remove a layer of indirection for convenience. */
     om = *om_ptr;
 
     LOG_STATS_INC(log, writes);
@@ -723,6 +810,9 @@ log_append_mbuf_typed_no_free(struct log *log, uint8_t module, uint8_t level,
 
     log_call_append_cb(log, hdr->ue_index);
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
     *om_ptr = om;
 
     return 0;
@@ -730,6 +820,9 @@ log_append_mbuf_typed_no_free(struct log *log, uint8_t module, uint8_t level,
 err:
     LOG_STATS_INC(log, errs);
 drop:
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
     if (om) {
         os_mbuf_free_chain(om);
         *om_ptr = NULL;
@@ -786,10 +879,17 @@ log_append_mbuf_body_no_free(struct log *log, uint8_t module, uint8_t level,
 
     log_call_append_cb(log, hdr.ue_index);
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
+
     return 0;
 err:
     LOG_STATS_INC(log, errs);
 drop:
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    log_trailer_free(log, log->l_tr_om, log->l_tr_arg);
+#endif
     return rc;
 }
 
@@ -932,6 +1032,20 @@ err:
     return rc;
 }
 
+/**
+ * Reads entry length from the specified log.
+ *
+ * @return                      The number of bytes of entry length; 0 on failure.
+ */
+uint16_t
+log_read_entry_len(struct log *log, const void *dptr)
+{
+    if (log->l_log->log_read_entry_len) {
+        return log->l_log->log_read_entry_len(log, dptr);
+    }
+    return 0;
+}
+
 /**
  * Reads from the specified log.
  *
@@ -951,7 +1065,7 @@ log_read(struct log *log, const void *dptr, void *buf, uint16_t off,
 int
 log_read_hdr(struct log *log, const void *dptr, struct log_entry_hdr *hdr)
 {
-    int bytes_read;
+    int bytes_read = 0;
 
     bytes_read = log_read(log, dptr, hdr, 0, LOG_BASE_ENTRY_HDR_SIZE);
     if (bytes_read != LOG_BASE_ENTRY_HDR_SIZE) {
@@ -1019,6 +1133,14 @@ log_flush(struct log *log)
 {
     int rc;
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    /* Reset trailer data if it exists, if it does not exist
+     * this function will return SYS_ENOTSUP. Currently,
+     * we do not use the return value.
+     */
+    log_trailer_reset_data(log, log->l_tr_arg);
+#endif
+
     rc = log->l_log->log_flush(log);
     if (rc != 0) {
         goto err;
