@@ -26,6 +26,7 @@
 #include "log/log.h"
 #include "tinycbor/cbor.h"
 #include "tinycbor/cbor_buf_reader.h"
+#include "datetime/datetime.h"
 
 static int
 log_console_dump_cbor_entry(const void *dptr, uint16_t len)
@@ -51,92 +52,71 @@ log_console_get(void)
 }
 
 #if MYNEWT_VAL(LOG_CONSOLE_PRETTY)
-#define CSI                     "\x1b["
-#define COLOR_BLACK             CSI "30m"
-#define COLOR_RED               CSI "31m"
-#define COLOR_GREEN             CSI "32m"
-#define COLOR_YELLOW            CSI "33m"
-#define COLOR_BLUE              CSI "34m"
-#define COLOR_MAGENTA           CSI "35m"
-#define COLOR_CYAN              CSI "36m"
-#define COLOR_WHITE             CSI "37m"
-#define COLOR_BLACK_BG          CSI "40m"
-#define COLOR_RED_BG            CSI "41m"
-#define COLOR_GREEN_BG          CSI "42m"
-#define COLOR_YELLOW_BG         CSI "43m"
-#define COLOR_WHITE_BG          CSI "47m"
 
 #if MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_COLORS)
-#define COLOR_DBG               COLOR_CYAN
-#define COLOR_INF               ""
-#define COLOR_WRN               COLOR_YELLOW
-#define COLOR_ERR               COLOR_RED
-#define COLOR_CRI               COLOR_RED_BG
-#define COLOR_RESET             CSI "0m"
 
-const char *const module_colors[] = {
-    COLOR_GREEN COLOR_BLACK_BG,
-    COLOR_RED COLOR_WHITE_BG,
-    COLOR_BLUE,
-    COLOR_YELLOW COLOR_BLACK_BG,
-    COLOR_MAGENTA COLOR_WHITE_BG,
-    COLOR_CYAN COLOR_BLACK_BG,
-    COLOR_WHITE COLOR_RED_BG,
-    COLOR_BLACK COLOR_GREEN_BG,
-    COLOR_BLACK COLOR_YELLOW_BG,
-};
+#define ANSI_CSI               "\x1b["
+#define ANSI_SEP               ";"
+#define ANSI_CSE               "m"
+#define ANSI_COLOR_RESET       ANSI_CSI "0" ANSI_CSE
+
+#define COLOR_BLACK             30
+#define COLOR_RED               31
+#define COLOR_GREEN             32
+#define COLOR_YELLOW            33
+#define COLOR_BLUE              34
+#define COLOR_MAGENTA           35
+#define COLOR_CYAN              36
+#define COLOR_WHITE             37
+
+#define MOD_COLOR_MIN           COLOR_GREEN
+#define MOD_COLOR_MAX           COLOR_CYAN
 
-static uint8_t log_module_color_index[10];
 
 static void
 log_module_color(uint8_t module, char *color_on, char *color_off)
 {
-    int i;
-
     *color_on = 0;
     *color_off = 0;
 
     if (module) {
-        for (i = 0; i < ARRAY_SIZE(log_module_color_index) &&
-             log_module_color_index[i] != 0 &&
-             log_module_color_index[i] != module; ++i) {
-        }
-        if (i < ARRAY_SIZE(log_module_color_index)) {
-            if (log_module_color_index[i] == 0) {
-                log_module_color_index[i] = module;
-            }
-            strcpy(color_on, module_colors[i]);
-            strcpy(color_off, COLOR_RESET);
-        }
+        sprintf(color_on, ANSI_CSI "%d" ANSI_SEP "%d" ANSI_CSE,
+                module < LOG_MODULE_PERUSER ? MYNEWT_VAL(LOG_COLOR_HILIGHT_MODULE) : 0,
+                MOD_COLOR_MIN + module % (MOD_COLOR_MAX - MOD_COLOR_MIN + 1));
+        strcpy(color_off, ANSI_COLOR_RESET);
     }
 }
 
 #else
-#define COLOR_DBG               ""
-#define COLOR_INF               ""
-#define COLOR_WRN               ""
-#define COLOR_ERR               ""
-#define COLOR_CRI               ""
-#define COLOR_RESET             ""
+#define ANSI_CSI                ""
+#define ANSI_SEP                ""
+#define ANSI_CSE                ""
+#define ANSI_COLOR_RESET        ""
 #define log_module_color(hdr, on, off)
 #endif
 
-static const char * const log_level_color[] = {
-    COLOR_DBG,
-    COLOR_INF,
-    COLOR_WRN,
-    COLOR_ERR,
-    COLOR_CRI,
+static const uint8_t log_level_color_code[] = {
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_DEBUG),
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_INFO),
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_WARNING),
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_ERROR),
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_CRITICAL),
+    /* Add new custom log levels here */
+    MYNEWT_VAL(LOG_LEVEL_COLOR_CODE_MAXIMUM),
 };
 
 static const char * const log_level_str[] = {
-    "DBG",
-    "INF",
-    "WRN",
-    "ERR",
-    "CRI",
+    MYNEWT_VAL(LOG_LEVEL_STRING_DEBUG),
+    MYNEWT_VAL(LOG_LEVEL_STRING_INFO),
+    MYNEWT_VAL(LOG_LEVEL_STRING_WARNING),
+    MYNEWT_VAL(LOG_LEVEL_STRING_ERROR),
+    MYNEWT_VAL(LOG_LEVEL_STRING_CRITICAL),
+    /* Add new custom log levels here */
+    MYNEWT_VAL(LOG_LEVEL_STRING_MAXIMUM),
 };
 
+static const int real_log_levels = ARRAY_SIZE(log_level_str) - 1;
+
 void
 log_console_print_hdr(const struct log_entry_hdr *hdr)
 {
@@ -145,17 +125,16 @@ log_console_print_hdr(const struct log_entry_hdr *hdr)
     char level_str_buf[23];
     const char *level_str = "";
     const char *module_name = NULL;
-    char color[11];
-    char color_off[6];
+    char color[11] = "";
+    char color_off[6] = "";
+    uint8_t mapped_log_level;
+    uint8_t color_code;
 
     /* Find module defined in syscfg.logcfg sections */
     module_name = log_module_get_name(hdr->ue_module);
 
-    if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_COLORS)) {
+    if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_COLOR_MODULES)) {
         log_module_color(hdr->ue_module, color, color_off);
-    } else {
-        color[0] = 0;
-        color_off[0] = 0;
     }
 
     if (module_name == NULL) {
@@ -168,21 +147,37 @@ log_console_print_hdr(const struct log_entry_hdr *hdr)
     } else {
         image_hash_str[0] = 0;
     }
-    if (hdr->ue_level <= LOG_LEVEL_CRITICAL) {
+    if (hdr->ue_level < real_log_levels || hdr->ue_level == LOG_LEVEL_MAX) {
+        mapped_log_level =
+            hdr->ue_level < real_log_levels ? hdr->ue_level : real_log_levels;
+        color_code = log_level_color_code[mapped_log_level];
         if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_COLORS)) {
-            strcpy(level_str_buf, log_level_color[hdr->ue_level]);
-            strcat(level_str_buf, log_level_str[hdr->ue_level]);
-            strcat(level_str_buf, COLOR_RESET);
+            sprintf(level_str_buf, ANSI_CSI "%d" ANSI_SEP "%d" ANSI_CSE "%s" ANSI_COLOR_RESET,
+                color_code >= 10 ? MYNEWT_VAL(LOG_COLOR_HILIGHT_LEVEL) : 0,
+                color_code % 10 + 30,
+                log_level_str[mapped_log_level]);
             level_str = level_str_buf;
         } else {
-            level_str = log_level_str[hdr->ue_level];
+            level_str = log_level_str[mapped_log_level];
         }
     } else {
         sprintf(level_str_buf, "%-3u", hdr->ue_level);
         level_str = level_str_buf;
     }
 
-    if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_TIMESTAMP)) {
+    if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_TIMESTAMP) &&
+        MYNEWT_VAL(LOG_CONSOLE_PRETTY_TIMESTAMP_CLOCK)) {
+        struct os_timeval tv = {
+            .tv_usec = (unsigned int)hdr->ue_ts % 1000000,
+            .tv_sec = (unsigned int)(hdr->ue_ts / 1000000),
+        };
+        struct clocktime ct;
+        timeval_to_clocktime(&tv, NULL, &ct);
+        console_printf("[%d-%02d-%02dT%02d:%02d:%02d.%06u][%s%7s%s][%s]%s ",
+                       ct.year, ct.mon, ct.day,
+                       ct.hour, ct.min, ct.sec, ct.usec,
+                       color, module_name, color_off, level_str, image_hash_str);
+    } else if (MYNEWT_VAL(LOG_CONSOLE_PRETTY_WITH_TIMESTAMP)) {
         unsigned int us = (unsigned int)hdr->ue_ts % 1000000;
         unsigned int s = (unsigned int)(hdr->ue_ts / 1000000);
         console_printf("[%u.%06u][%s%7s%s][%s]%s ", s, us, color, module_name, color_off, level_str, image_hash_str);
@@ -220,6 +215,9 @@ log_console_append_body(struct log *log, const struct log_entry_hdr *hdr,
 
     if (hdr->ue_etype != LOG_ETYPE_CBOR) {
         console_write(body, body_len);
+        if (((const uint8_t *)body)[body_len - 1] != '\n') {
+            console_out('\n');
+        }
     } else {
         log_console_dump_cbor_entry(body, body_len);
     }
