@@ -30,6 +30,13 @@
 /* Assume the flash alignment requirement is no stricter than 32. */
 #define LOG_FCB_MAX_ALIGN   32
 
+#define LOG_FCB_EXT_HDR_SIZE LOG_BASE_ENTRY_HDR_SIZE + LOG_IMG_HASHLEN + \
+    LOG_FCB_MAX_ALIGN
+
+/* Assuming the trailer fits in this, an arbitrary value */
+#define LOG_FCB_FLAT_BUF_SIZE (LOG_FCB_EXT_HDR_SIZE > LOG_FCB_MAX_ALIGN * 2) ? \
+    LOG_FCB_EXT_HDR_SIZE : LOG_FCB_MAX_ALIGN * 2
+
 static int log_fcb_rtr_erase(struct log *log);
 
 static int
@@ -53,7 +60,9 @@ fcb_get_fa_hdr(struct fcb *fcb, struct log *log, struct fcb_entry *fcb_entry, st
  * given offset is found, start walking from there.
  */
 static int
-fcb_walk_back_find_start(struct fcb *fcb, struct log *log, struct log_offset *log_offset, struct fcb_entry *fcb_entry)
+fcb_walk_back_find_start(struct fcb *fcb, struct log *log,
+                         struct log_offset *log_offset,
+                         struct fcb_entry *fcb_entry)
 {
     struct flash_area *fap;
     struct log_entry_hdr hdr;
@@ -111,6 +120,10 @@ found_ent:
  *
  * The "index" field corresponds to a log entry index.
  *
+ * If bookmark is found with the minimum difference in indices, min_diff contains
+ * the difference else it will contain -1 if no bookmark is found. min_diff is 0
+ * means an exact match.
+ *
  * If bookmarks are enabled, this function uses them in the search.
  *
  * @return                      0 if an entry was found
@@ -119,7 +132,7 @@ found_ent:
  */
 static int
 log_fcb_find_gte(struct log *log, struct log_offset *log_offset,
-                 struct fcb_entry *out_entry)
+                 struct fcb_entry *out_entry, int *min_diff)
 {
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
     const struct log_fcb_bmark *bmark;
@@ -149,7 +162,8 @@ log_fcb_find_gte(struct log *log, struct log_offset *log_offset,
      * if timestamp for request is < 0, return last log entry
      */
     if (log_offset->lo_ts < 0) {
-        out_entry->fe_step_back = false;
+        *out_entry = fcb->f_active;
+        out_entry->fe_step_back = true;
         return 0;
     }
 
@@ -165,7 +179,7 @@ log_fcb_find_gte(struct log *log, struct log_offset *log_offset,
     }
 
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
-    bmark = log_fcb_closest_bmark(fcb_log, log_offset->lo_index);
+    bmark = log_fcb_closest_bmark(fcb_log, log_offset->lo_index, min_diff);
     if (bmark != NULL) {
         *out_entry = bmark->lfb_entry;
         bmark_found = true;
@@ -204,17 +218,24 @@ log_fcb_find_gte(struct log *log, struct log_offset *log_offset,
 static int
 log_fcb_start_append(struct log *log, int len, struct fcb_entry *loc)
 {
-    struct fcb *fcb;
-    struct fcb_log *fcb_log;
+    struct fcb_log *fcb_log = (struct fcb_log *)log->l_arg;
+    struct fcb *fcb = &fcb_log->fl_fcb;
     struct flash_area *old_fa;
     int rc = 0;
+#if MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+    int active_id;
+    uint32_t idx;
+    struct log_fcb_bset *bset = &fcb_log->fl_bset;
+#endif
+
 #if MYNEWT_VAL(LOG_STATS)
     int cnt;
 #endif
 
-    fcb_log = (struct fcb_log *)log->l_arg;
-    fcb = &fcb_log->fl_fcb;
-
+    /* Cache active ID before appending */
+#if MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+    active_id = fcb->f_active_id;
+#endif
     while (1) {
         rc = fcb_append(fcb, len, loc);
         if (rc == 0) {
@@ -249,8 +270,10 @@ log_fcb_start_append(struct log *log, int len, struct fcb_entry *loc)
             log->l_rotate_notify_cb(log);
         }
 
-#if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
-        /* The FCB needs to be rotated. */
+#if MYNEWT_VAL(LOG_FCB_BOOKMARKS) && !MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+        /* The FCB needs to be rotated. For sector bookmarks
+         * we just re-initialize the bookmarks
+         */
         log_fcb_rotate_bmarks(fcb_log);
 #endif
 
@@ -259,6 +282,14 @@ log_fcb_start_append(struct log *log, int len, struct fcb_entry *loc)
             goto err;
         }
 
+#if MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+        /* The FCB needs to be rotated, reinit previously allocated
+         * bookmarks
+         */
+        log_fcb_init_bmarks(fcb_log, bset->lfs_bmarks, bset->lfs_cap,
+                            bset->lfs_en_sect_bmarks);
+#endif
+
 #if MYNEWT_VAL(LOG_STORAGE_WATERMARK)
         /*
          * FCB was rotated successfully so let's check if watermark was within
@@ -272,24 +303,43 @@ log_fcb_start_append(struct log *log, int len, struct fcb_entry *loc)
 #endif
     }
 
+#if MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+    /* Add bookmark if entry is added to a new sector */
+    if (!rc && log->l_log->log_type != LOG_TYPE_STREAM) {
+        /* If sector bookmarks are enabled, add a bookmark if the entry is
+         * added to a new sector (active_id change) or if the the first sector
+         * bookmark is not set yet.
+         */
+        if (bset->lfs_en_sect_bmarks &&
+            (!bset->lfs_bmarks[bset->lfs_sect_cap - 1].lfb_entry.fe_area ||
+             fcb->f_active_id != active_id)) {
+#if MYNEWT_VAL(LOG_GLOBAL_IDX)
+            idx = g_log_info.li_next_index;
+#else
+            idx = log->l_idx;
+#endif
+            if (!bset->lfs_bmarks[bset->lfs_sect_cap - 1].lfb_entry.fe_area) {
+                bset->lfs_next_sect = bset->lfs_sect_cap - 1;
+            }
+
+            log_fcb_add_bmark(fcb_log, loc, idx, true);
+        }
+    }
+#endif
+
 err:
     return (rc);
 }
 
-/**
- * Calculates the number of message body bytes that should be included after
- * the entry header in the first write.  Inclusion of body bytes is necessary
- * to satisfy the flash hardware's write alignment restrictions.
- */
 static int
-log_fcb_hdr_body_bytes(uint8_t align, uint8_t hdr_len)
+log_fcb_hdr_bytes(uint16_t align, uint16_t len)
 {
-    uint8_t mod;
+    uint16_t mod;
 
     /* Assume power-of-two alignment for faster modulo calculation. */
     assert((align & (align - 1)) == 0);
 
-    mod = hdr_len & (align - 1);
+    mod = len & (align - 1);
     if (mod == 0) {
         return 0;
     }
@@ -301,37 +351,40 @@ static int
 log_fcb_append_body(struct log *log, const struct log_entry_hdr *hdr,
                     const void *body, int body_len)
 {
-    uint8_t buf[LOG_BASE_ENTRY_HDR_SIZE + LOG_IMG_HASHLEN +
-                LOG_FCB_MAX_ALIGN - 1];
+    uint8_t buf[LOG_FCB_FLAT_BUF_SIZE] = {0};
     struct fcb *fcb;
-    struct fcb_entry loc;
+    struct fcb_entry loc = {};
     struct fcb_log *fcb_log;
     const uint8_t *u8p;
     int hdr_alignment;
-    int chunk_sz;
+    int chunk_sz = 0;
     int rc;
     uint16_t hdr_len;
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    int trailer_alignment = 0;
+    uint16_t trailer_len = 0;
+#endif
+    uint16_t padding = 0;
+    uint16_t offset = 0;
 
     fcb_log = (struct fcb_log *)log->l_arg;
     fcb = &fcb_log->fl_fcb;
 
+    (void)offset;
+    (void)padding;
+
     if (fcb->f_align > LOG_FCB_MAX_ALIGN) {
         return SYS_ENOTSUP;
     }
 
     hdr_len = log_hdr_len(hdr);
 
-    rc = log_fcb_start_append(log, hdr_len + body_len, &loc);
-    if (rc != 0) {
-        return rc;
-    }
-
     /* Append the first chunk (header + x-bytes of body, where x is however
      * many bytes are required to increase the chunk size up to a multiple of
      * the flash alignment). If the hash flag is set, we have to account for
      * appending the hash right after the header.
      */
-    hdr_alignment = log_fcb_hdr_body_bytes(fcb->f_align, hdr_len);
+    hdr_alignment = log_fcb_hdr_bytes(fcb->f_align, hdr_len);
     if (hdr_alignment > body_len) {
         chunk_sz = hdr_len + body_len;
     } else {
@@ -349,8 +402,36 @@ log_fcb_append_body(struct log *log, const struct log_entry_hdr *hdr,
     if (hdr->ue_flags & LOG_FLAGS_IMG_HASH) {
         memcpy(buf + LOG_BASE_ENTRY_HDR_SIZE, hdr->ue_imghash, LOG_IMG_HASHLEN);
     }
+
     memcpy(buf + hdr_len, u8p, hdr_alignment);
 
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    if (hdr->ue_flags & LOG_FLAGS_TRAILER && log->l_tr_om) {
+        /* Calculate trailer alignment */
+        trailer_alignment = log_fcb_hdr_bytes(fcb->f_align,
+                                              chunk_sz + body_len -
+                                              hdr_alignment);
+        /* If trailer is set, we need to write the trailer length and
+         * trailer data after the body.
+         * ------------------------------------------------------
+         * | hdr + align | body | align + trailer | trailer len |
+         * ------------------------------------------------------
+         */
+        trailer_len = os_mbuf_len(log->l_tr_om);
+        rc = log_fcb_start_append(log, hdr_len + body_len + trailer_len +
+                                  trailer_alignment + LOG_TRAILER_LEN_SIZE,
+                                  &loc);
+    } else
+#endif
+    {
+        /* If trailer is not set, we just write the header + body */
+        rc = log_fcb_start_append(log, hdr_len + body_len, &loc);
+    }
+
+    if (rc != 0) {
+        return rc;
+    }
+
     rc = fcb_write(fcb, &loc, buf, chunk_sz);
     if (rc != 0) {
         return rc;
@@ -359,13 +440,59 @@ log_fcb_append_body(struct log *log, const struct log_entry_hdr *hdr,
     /* Append the remainder of the message body. */
 
     u8p += hdr_alignment;
-    body_len -= hdr_alignment;
+    if (body_len > hdr_alignment) {
+        body_len -= hdr_alignment;
+    }
+
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    if (hdr->ue_flags & LOG_FLAGS_TRAILER && log->l_tr_om) {
+        memset(buf, 0, sizeof(buf));
+        padding = trailer_alignment ? fcb->f_align - trailer_alignment : 0;
+        /* This writes padding + trailer_alignment if needed */
+        if (body_len > padding) {
+            /* Writes body - padding bytes */
+            rc = fcb_write(fcb, &loc, u8p, body_len - padding);
+            u8p += (body_len - padding);
+            memcpy(buf, u8p, padding);
+            offset = padding;
+        } else {
+            /* Just write the entire body since its less than padding */
+            rc = fcb_write(fcb, &loc, u8p, body_len);
+            u8p += body_len;
+        }
 
-    if (body_len > 0) {
-        rc = fcb_write(fcb, &loc, u8p, body_len);
         if (rc != 0) {
             return rc;
         }
+
+        offset += trailer_alignment;
+
+        rc = os_mbuf_copydata(log->l_tr_om, 0, trailer_len, buf + offset);
+        if (rc) {
+            return rc;
+        }
+        offset += trailer_len;
+        memcpy(buf + offset, &trailer_len, LOG_TRAILER_LEN_SIZE);
+        offset += LOG_TRAILER_LEN_SIZE;
+
+        /* Writes the following:
+         * ------------------------------------------------------------------
+         * | body: [padding] | trailer_alignment | trailer | trailer length |
+         * ------------------------------------------------------------------
+         *
+         * Padding is optional based on whether body_len > padding.
+         */
+        rc = fcb_write(fcb, &loc, buf, offset);
+    } else
+#endif
+    {
+        if (body_len > 0) {
+            rc = fcb_write(fcb, &loc, u8p, body_len);
+        }
+    }
+
+    if (rc != 0) {
+        return rc;
     }
 
     rc = fcb_append_finish(fcb, &loc);
@@ -411,10 +538,16 @@ log_fcb_append_mbuf_body(struct log *log, const struct log_entry_hdr *hdr,
                          struct os_mbuf *om)
 {
     struct fcb *fcb;
-    struct fcb_entry loc;
+    struct fcb_entry loc = {};
     struct fcb_log *fcb_log;
     int len;
     int rc;
+    uint16_t buflen = 0;
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    int trailer_alignment = 0;
+    uint8_t pad[LOG_FCB_MAX_ALIGN] = {0};
+    uint16_t trailer_len = 0;
+#endif
 
     fcb_log = (struct fcb_log *)log->l_arg;
     fcb = &fcb_log->fl_fcb;
@@ -426,7 +559,30 @@ log_fcb_append_mbuf_body(struct log *log, const struct log_entry_hdr *hdr,
         return SYS_ENOTSUP;
     }
 
-    len = log_hdr_len(hdr) + os_mbuf_len(om);
+    buflen = os_mbuf_len(om);
+    len = log_hdr_len(hdr) + buflen;
+
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    if (hdr->ue_flags & LOG_FLAGS_TRAILER) {
+        /* The trailer gets appended after the trailer_alignment
+         * Trailers start from updated loc.fe_data_off. Write everything
+         * together
+         * Writes the following:
+         * -----------------------------------------------------------------
+         * | body: body_len | trailer_alignment | trailer | trailer length |
+         * -----------------------------------------------------------------
+         * part of body len + trailer_alignment = fcb->f_align
+         * So, we just pad trailer_alignment agt the end of the mbuf chain
+         */
+        if (log->l_tr_om) {
+            trailer_len = os_mbuf_len(log->l_tr_om);
+            /* Calculate trailer alignment */
+            trailer_alignment = log_fcb_hdr_bytes(fcb->f_align, trailer_len);
+            len += (trailer_alignment + trailer_len + LOG_TRAILER_LEN_SIZE);
+        }
+    }
+#endif
+
     rc = log_fcb_start_append(log, len, &loc);
     if (rc != 0) {
         return rc;
@@ -448,6 +604,45 @@ log_fcb_append_mbuf_body(struct log *log, const struct log_entry_hdr *hdr,
         }
         loc.fe_data_off += LOG_IMG_HASHLEN;
     }
+
+#if MYNEWT_VAL(LOG_FLAGS_TRAILER)
+    if (hdr->ue_flags & LOG_FLAGS_TRAILER) {
+        /* The trailer gets appended after the padding + trailer_alignment
+         * Trailers start from updated loc.fe_data_off. Write everything
+         * together
+         * Writes the following:
+         * -----------------------------------------------------------------
+         * | body: body_len | trailer_alignment | trailer | trailer length |
+         * -----------------------------------------------------------------
+         * part of body_len + trailer_alignment = f_align
+         */
+
+        if (log->l_tr_om) {
+            if (trailer_alignment) {
+                /* Copy padding for trailer alignment */
+                rc = os_mbuf_copyinto(om, buflen, pad, trailer_alignment);
+                if (rc) {
+                    return rc;
+                }
+            }
+
+            /* Append from the trailer */
+            rc = os_mbuf_appendfrom(om, log->l_tr_om, 0, trailer_len);
+            if (rc) {
+                return rc;
+            }
+
+            om = os_mbuf_pullup(om, LOG_TRAILER_LEN_SIZE);
+            /* Copy the trailer length */
+            rc = os_mbuf_copyinto(om, buflen + trailer_alignment + trailer_len,
+                                  &trailer_len, LOG_TRAILER_LEN_SIZE);
+            if (rc) {
+                return rc;
+            }
+        }
+    }
+#endif
+
     rc = log_fcb_write_mbuf(&loc, om);
     if (rc != 0) {
         return rc;
@@ -503,6 +698,20 @@ log_fcb_append_mbuf(struct log *log, struct os_mbuf *om)
     return rc;
 }
 
+static uint16_t
+log_fcb_read_entry_len(struct log *log, const void *dptr)
+{
+    struct fcb_entry *loc;
+
+    loc = (struct fcb_entry *)dptr;
+
+    if (!log || !dptr) {
+        return 0;
+    }
+
+    return loc->fe_data_len;
+}
+
 static int
 log_fcb_read(struct log *log, const void *dptr, void *buf, uint16_t offset,
   uint16_t len)
@@ -577,16 +786,17 @@ log_fcb_walk_impl(struct log *log, log_walk_func_t walk_func,
 {
     struct fcb *fcb;
     struct fcb_log *fcb_log;
-    struct fcb_entry loc;
+    struct fcb_entry loc = {};
     struct flash_area *fap;
     int rc;
     struct fcb_entry_cache cache;
+    int min_diff = -1;
 
     fcb_log = log->l_arg;
     fcb = &fcb_log->fl_fcb;
 
     /* Locate the starting point of the walk. */
-    rc = log_fcb_find_gte(log, log_offset, &loc);
+    rc = log_fcb_find_gte(log, log_offset, &loc, &min_diff);
     switch (rc) {
     case 0:
         /* Found a starting point. */
@@ -610,9 +820,12 @@ log_fcb_walk_impl(struct log *log, log_walk_func_t walk_func,
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
     /* If a minimum index was specified (i.e., we are not just retrieving the
      * last entry), add a bookmark pointing to this walk's start location.
+     * Only add a bmark if the index is non-zero and an exactly matching bmark
+     * was not found. If an exactly matching bmark was found, min_diff is 0,
+     * else it stays -1 or is great than 0.
      */
-    if (log_offset->lo_ts >= 0) {
-        log_fcb_add_bmark(fcb_log, &loc, log_offset->lo_index);
+    if ((log_offset->lo_ts >= 0 && log_offset->lo_index > 0) && min_diff != 0) {
+        log_fcb_add_bmark(fcb_log, &loc, log_offset->lo_index, false);
     }
 #endif
 
@@ -659,29 +872,39 @@ log_fcb_flush(struct log *log)
 {
     struct fcb_log *fcb_log;
     struct fcb *fcb;
+    int rc;
 
     fcb_log = (struct fcb_log *)log->l_arg;
     fcb = &fcb_log->fl_fcb;
 
+    rc = fcb_clear(fcb);
+
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
+#if MYNEWT_VAL(LOG_FCB_SECTOR_BOOKMARKS)
+    /* Reinit previously allocated bookmarks */
+    log_fcb_init_bmarks(fcb_log, fcb_log->fl_bset.lfs_bmarks,
+                        fcb_log->fl_bset.lfs_cap,
+                        fcb_log->fl_bset.lfs_en_sect_bmarks);
+#else
     log_fcb_clear_bmarks(fcb_log);
+#endif
 #endif
 
-    return fcb_clear(fcb);
+    return rc;
 }
 
 static int
 log_fcb_registered(struct log *log)
 {
+    struct fcb_log *fl = (struct fcb_log *)log->l_arg;
+
+    fl->fl_log = log;
 #if MYNEWT_VAL(LOG_STORAGE_WATERMARK)
-    struct fcb_log *fl;
 #if MYNEWT_VAL(LOG_PERSIST_WATERMARK)
     struct fcb *fcb;
     struct fcb_entry loc;
 #endif
 
-    fl = (struct fcb_log *)log->l_arg;
-
 #if MYNEWT_VAL(LOG_PERSIST_WATERMARK)
     fcb = &fl->fl_fcb;
 
@@ -804,7 +1027,7 @@ static int
 log_fcb_set_watermark(struct log *log, uint32_t index)
 {
     int rc;
-    struct log_offset log_offset;
+    struct log_offset log_offset = {};
     struct fcb_log *fl;
     struct fcb *fcb;
 
@@ -852,7 +1075,8 @@ log_fcb_copy_entry(struct log *log, struct fcb_entry *entry,
     uint16_t hdr_len;
     int dlen;
     int rc;
-    struct fcb *fcb_tmp;
+    struct fcb_log fcb_log_tmp;
+    struct fcb_log *fcb_log_ptr;
 
     rc = log_fcb_read(log, entry, &ueh, 0, LOG_BASE_ENTRY_HDR_SIZE);
 
@@ -870,12 +1094,19 @@ log_fcb_copy_entry(struct log *log, struct fcb_entry *entry,
         goto err;
     }
 
-    /* Changing the fcb to be logged to be dst fcb */
-    fcb_tmp = &((struct fcb_log *)log->l_arg)->fl_fcb;
+    /* Cache fcb_log pointer */
+    fcb_log_ptr = (struct fcb_log *)log->l_arg;
 
-    log->l_arg = dst_fcb;
+    /* Cache the fcb log, so that we preserve original fcb pointer */
+    fcb_log_tmp = *fcb_log_ptr;
+    fcb_log_tmp.fl_fcb = *dst_fcb;
+    log->l_arg = &fcb_log_tmp;
     rc = log_fcb_append(log, data, dlen);
-    log->l_arg = fcb_tmp;
+
+    /* Restore the original fcb_log pointer */
+    log->l_arg = fcb_log_ptr;
+    *dst_fcb = fcb_log_tmp.fl_fcb;
+
     if (rc) {
         goto err;
     }
@@ -890,24 +1121,19 @@ err:
  * @param log      Log this operation applies to
  * @param src_fcb  FCB area which is the source of data
  * @param dst_fcb  FCB area which is the target
- * @param offset   Flash offset where to start the copy
+ * @param entry    Location in src_fcb to start copy from
  *
  * @return 0 on success; non-zero on error
  */
 static int
 log_fcb_copy(struct log *log, struct fcb *src_fcb, struct fcb *dst_fcb,
-             uint32_t offset)
+             struct fcb_entry *entry)
 {
-    struct fcb_entry entry;
     int rc;
 
     rc = 0;
-    memset(&entry, 0, sizeof(entry));
-    while (!fcb_getnext(src_fcb, &entry)) {
-        if (entry.fe_elem_off < offset) {
-            continue;
-        }
-        rc = log_fcb_copy_entry(log, &entry, dst_fcb);
+    while (!fcb_getnext(src_fcb, entry)) {
+        rc = log_fcb_copy_entry(log, entry, dst_fcb);
         if (rc) {
             break;
         }
@@ -931,7 +1157,7 @@ log_fcb_rtr_erase(struct log *log)
     struct fcb fcb_scratch;
     struct fcb *fcb;
     const struct flash_area *ptr;
-    struct fcb_entry entry;
+    struct fcb_entry entry = {};
     int rc;
     struct flash_area sector;
 
@@ -968,7 +1194,7 @@ log_fcb_rtr_erase(struct log *log)
     }
 
     /* Copy to scratch */
-    rc = log_fcb_copy(log, fcb, &fcb_scratch, entry.fe_elem_off);
+    rc = log_fcb_copy(log, fcb, &fcb_scratch, &entry);
     if (rc) {
         goto err;
     }
@@ -979,8 +1205,9 @@ log_fcb_rtr_erase(struct log *log)
         goto err;
     }
 
+    memset(&entry, 0, sizeof(entry));
     /* Copy back from scratch */
-    rc = log_fcb_copy(log, &fcb_scratch, fcb, 0);
+    rc = log_fcb_copy(log, &fcb_scratch, fcb, &entry);
 
 err:
     return (rc);
@@ -997,6 +1224,7 @@ const struct log_handler log_fcb_handler = {
     .log_walk             = log_fcb_walk,
     .log_walk_sector      = log_fcb_walk_area,
     .log_flush            = log_fcb_flush,
+    .log_read_entry_len   = log_fcb_read_entry_len,
 #if MYNEWT_VAL(LOG_STORAGE_INFO)
     .log_storage_info     = log_fcb_storage_info,
 #endif
