@@ -46,7 +46,10 @@ static int log_fcb2_rtr_erase(struct log *log);
  *
  * The "index" field corresponds to a log entry index.
  *
- * If bookmarks are enabled, this function uses them in the search.
+ *
+ * If bookmark is found with the minimum difference in indexes, min_diff contains
+ * the difference else it will contain -1 if no bookmark is found. min_diff is 0
+ * means an exact match.
  *
  * @return                      0 if an entry was found
  *                              SYS_ENOENT if there are no suitable entries.
@@ -54,7 +57,7 @@ static int log_fcb2_rtr_erase(struct log *log);
  */
 static int
 log_fcb2_find_gte(struct log *log, struct log_offset *log_offset,
-                  struct fcb2_entry *out_entry)
+                  struct fcb2_entry *out_entry, int *min_diff)
 {
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
     const struct log_fcb_bmark *bmark;
@@ -67,6 +70,7 @@ log_fcb2_find_gte(struct log *log, struct log_offset *log_offset,
     fcb_log = log->l_arg;
     fcb = &fcb_log->fl_fcb;
 
+    (void)min_diff;
     /* Attempt to read the last entry.  If this fails, the FCB is empty. */
     memset(out_entry, 0, sizeof(*out_entry));
     rc = fcb2_getprev(fcb, out_entry);
@@ -103,7 +107,7 @@ log_fcb2_find_gte(struct log *log, struct log_offset *log_offset,
         return SYS_EUNKNOWN;
     }
 #if MYNEWT_VAL(LOG_FCB_BOOKMARKS)
-    bmark = log_fcb_closest_bmark(fcb_log, log_offset->lo_index);
+    bmark = log_fcb_closest_bmark(fcb_log, log_offset->lo_index, min_diff);
     if (bmark != NULL) {
         *out_entry = bmark->lfb_entry;
     }
@@ -476,12 +480,13 @@ log_fcb2_walk(struct log *log, log_walk_func_t walk_func,
     struct fcb_log *fcb_log;
     struct fcb2_entry loc;
     int rc;
+    int min_diff = -1;
 
     fcb_log = log->l_arg;
     fcb = &fcb_log->fl_fcb;
 
     /* Locate the starting point of the walk. */
-    rc = log_fcb2_find_gte(log, log_off, &loc);
+    rc = log_fcb2_find_gte(log, log_off, &loc, &min_diff);
     switch (rc) {
     case 0:
         /* Found a starting point. */
@@ -497,8 +502,8 @@ log_fcb2_walk(struct log *log, log_walk_func_t walk_func,
     /* If a minimum index was specified (i.e., we are not just retrieving the
      * last entry), add a bookmark pointing to this walk's start location.
      */
-    if (log_off->lo_ts >= 0) {
-        log_fcb_add_bmark(fcb_log, &loc, log_off->lo_index);
+    if ((log_off->lo_ts >= 0 && log_off->lo_index > 0) && min_diff != 0) {
+        log_fcb_add_bmark(fcb_log, &loc, log_off->lo_index, false);
     }
 #endif
 
@@ -537,14 +542,15 @@ log_fcb2_registered(struct log *log)
 {
     struct fcb2 *fcb;
     int i;
-    struct fcb_log *fl;
+    struct fcb_log *fl = (struct fcb_log *)log->l_arg;
+
 #if MYNEWT_VAL(LOG_STORAGE_WATERMARK)
 #if MYNEWT_VAL(LOG_PERSIST_WATERMARK)
     struct fcb2_entry loc;
 #endif
 #endif
+    fl->fl_log = log;
 
-    fl = (struct fcb_log *)log->l_arg;
     fcb = &fl->fl_fcb;
 
     for (i = 0; i < fcb->f_range_cnt; i++) {
@@ -693,7 +699,7 @@ static int
 log_fcb2_set_watermark(struct log *log, uint32_t index)
 {
     int rc;
-    struct log_offset log_offset;
+    struct log_offset log_offset = {};
     struct fcb_log *fl;
     struct fcb2 *fcb;
 
