@@ -20,21 +20,12 @@
 #include "os/mynewt.h"
 
 #if MYNEWT_VAL(CRASH_TEST_CLI)
-#include <inttypes.h>
 #include <console/console.h>
 #include <shell/shell.h>
-#include <stdio.h>
 #include <string.h>
 
-#include "crash_test/crash_test.h"
 #include "crash_test_priv.h"
 
-static int crash_cli_cmd(int argc, char **argv);
-struct shell_cmd crash_cmd_struct = {
-    .sc_cmd = "crash",
-    .sc_cmd_func = crash_cli_cmd
-};
-
 static int
 crash_cli_cmd(int argc, char **argv)
 {
@@ -45,4 +36,6 @@ crash_cli_cmd(int argc, char **argv)
     return 0;
 }
 
+MAKE_SHELL_CMD(crash, crash_cli_cmd, NULL)
+
 #endif /* MYNEWT_VAL(CRASH_TEST_CLI) */
